==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGridSelectionRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDescription } from "./WebGridSelectionRangeDescription";
/**
 * @hidden
 */
export let WebGridSelectionRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridSelectionRangeDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridSelectionRangeDescriptionMetadata.a == null) {
                WebGridSelectionRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridSelectionRangeDescriptionMetadata.c(WebGridSelectionRangeDescriptionMetadata.a);
            }
            if (a.k(WebGridSelectionRangeDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridSelectionRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridSelectionRange");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("RowStart", "Number:double");
            a.item("RowEnd", "Number:double");
            a.item("ColumnStart", "String");
            a.item("ColumnEnd", "String");
        }
        static d(a) {
            WebGridSelectionRangeDescriptionMetadata.b(a);
            a.ad("WebGridSelectionRange", () => new WebGridSelectionRangeDescription());
            a.ac("WebGridSelectionRange", WebGridSelectionRangeDescriptionMetadata.a);
        }
    }
    WebGridSelectionRangeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridSelectionRangeDescriptionMetadata, 'WebGridSelectionRangeDescriptionMetadata');
    WebGridSelectionRangeDescriptionMetadata.a = null;
    return WebGridSelectionRangeDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebGridSelectionRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDescription } from "./WebGridSelectionRangeDescription";
/**
 * @hidden
 */
export let WebGridSelectionRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridSelectionRangeDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridSelectionRangeDescriptionMetadata.a == null) {
                WebGridSelectionRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridSelectionRangeDescriptionMetadata.c(WebGridSelectionRangeDescriptionMetadata.a);
            }
            if (a.k(WebGridSelectionRangeDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridSelectionRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridSelectionRange");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("__isTSPlainInterface", "Boolean");
            a.item("RowStart", "Number:double");
            a.item("RowEnd", "Number:double");
            a.item("ColumnStart", "Number:double");
            a.item("ColumnEnd", "Number:double");
        }
        static d(a) {
            WebGridSelectionRangeDescriptionMetadata.b(a);
            a.ae("WebGridSelectionRange", () => new WebGridSelectionRangeDescription());
            a.ad("WebGridSelectionRange", WebGridSelectionRangeDescriptionMetadata.a);
        }
    }
    WebGridSelectionRangeDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridSelectionRangeDescriptionMetadata, 'WebGridSelectionRangeDescriptionMetadata');
    WebGridSelectionRangeDescriptionMetadata.a = null;
    return WebGridSelectionRangeDescriptionMetadata;
})();
